import{d as s,a5 as m,z as n,X as e,c as l,g as c,f as u,b as f}from"./index-5e5d70f8.js";import{I as h}from"./ItemsListing-d367002d.js";import"./VCheckbox-e50bb5e3.js";import"./eventbus-5e9bd59e.js";import"./VListItem-a276ed14.js";import"./VCheckboxBtn-d41d6adf.js";import"./VList-1bffb8df.js";import"./VCardText-bdfad4e5.js";import"./VCard-35632c3b.js";import"./VMenu-4ca080f5.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-f9f543a5.js";import"./Button-558e640e.js";import"./VSpacer-3df5a092.js";/* empty css              */import"./PanelviewItemCompact-5dcada9d.js";import"./VAlert-8c135db5.js";import"./Container-39ff39e9.js";import"./Toolbar-9ec9e26d.js";import"./VToolbar-c09ee689.js";import"./VTextField-fa7e9a48.js";import"./VInfiniteScroll-01a7fa67.js";import"./layout-41b62dfb.js";import"./VVirtualScroll-a35573be.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{J as default};
